Method: Appium::Android::Espresso::Element#scroll_to_exact

Defined in:
lib/appium_lib/android/espresso/element/generic.rb

#scroll_to_exact(text) ⇒ Element

Scroll to the first element with the exact target text or description. Scroll happens upto 30 times in centre of device width.

Parameters:

  • text (String)

    the text or resourceId to search for in the text value and content description

Returns:

  • (Element)

    the element scrolled to



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/appium_lib/android/espresso/element/generic.rb', line 48

def scroll_to_exact(text)
  err = nil
  w_s = window_rect

  (1..30).each do |_count|
    action
      .move_to_location(w_s.width / 2, (w_s.height * 2) / 5) # pointer based magic number
      .pointer_down(:left)
      .move_to_location(0, w_s.height / 5)
      .release
      .perform
    sleep 1 # we must wait finish scrolling

    return text_exact(text)
  rescue StandardError => e
    err = e
  end

  raise err
end